@@ -12,8 +12,8 @@
 #' @import data.table
 #' 
 #' @examples
-#' calc_nleach('dekzand',265,'GtIII',145,'Zuidwest-Brabant','gw')
-#' calc_nleach('rivierklei',1019,'GtIV',145,'Rivierengebied','ow')
+#' calc_nleach('dekzand',265,'III',145,'Zuidwest-Brabant','gw')
+#' calc_nleach('rivierklei',1019,'IV',145,'Rivierengebied','ow')
 #' 
 #' @return 
 #' The potential nitrogen leaching from the soil originating from soil nitrogen mineralization processes. A numeric value.
@@ -21,7 +21,7 @@
 #' @export
 calc_nleach <- function(B_SOILTYPE_AGR, B_LU_BRP, B_GWL_CLASS, D_NLV, B_AER_CBS, leaching_to){
   
-  soiltype = crop_code = crop_category = soiltype.n = croptype.nleach = B_GT = med_nlv = NULL
+  soiltype = crop_code = crop_category = soiltype.n = croptype.nleach = med_nlv = NULL
   nleach_table = bodem = gewas = nf = id = leaching_to_set = NULL
   n_eff = anr.cor = n_sp.nlv = n_sp.nfert = n_sp = NULL
   nf_sand.other = nf_sand.south = nf_clay = nf_peat = nf_loess = NULL
@@ -43,6 +43,11 @@ calc_nleach <- function(B_SOILTYPE_AGR, B_LU_BRP, B_GWL_CLASS, D_NLV, B_AER_CBS,
   checkmate::assert_numeric(B_LU_BRP, any.missing = FALSE, min.len = 1, len = arg.length)
   checkmate::assert_subset(B_LU_BRP, choices = unique(crops.obic$crop_code), empty.ok = FALSE)
   checkmate::assert_character(B_GWL_CLASS,any.missing = FALSE, len = arg.length)
+  checkmate::assert_subset(B_GWL_CLASS, choices = c(
+    "I", "Ia", "Ic", "II", "IIa", "IIb", "IIc", "III", "IIIa", "IIIb", "IV",
+    "IVc", "IVu", "sV", "sVb", "V", "Va", "Vad", "Vao", "Vb", "Vbd", "Vbo", "VI", 
+    "VId", "VII", "VIId", "VIII", "VIIId", "VIIIo", "VIIo", "VIo"
+  ), empty.ok = FALSE)
   checkmate::assert_numeric(D_NLV, lower = -30, upper = 250, len = arg.length) 
   checkmate::assert_choice(leaching_to, choices = c("gw", "ow"), null.ok = FALSE)
   checkmate::assert_character(B_AER_CBS, any.missing = FALSE, min.len = 1, len = arg.length)
@@ -73,13 +78,10 @@ calc_nleach <- function(B_SOILTYPE_AGR, B_LU_BRP, B_GWL_CLASS, D_NLV, B_AER_CBS,
   dt[crop_category == "natuur" | crop_category == "akkerbouw" , croptype.nleach := "akkerbouw"]
   dt[crop_category == "grasland" , croptype.nleach := "gras"]
   
-  # ensure correct GWL_CLASS
-  dt[,B_GWL_CLASS := format_gwt(B_GWL_CLASS)]
-  
   # merge fraction of N leaching into 'dt', based on soil type x crop type x grondwatertrap
-  dt <- merge(dt, nleach_table[, list(bodem, gewas, B_GT, nf)], 
+  dt <- merge(dt, nleach_table[, list(bodem, gewas, B_GWL_CLASS, nf)], 
               by.x = c("soiltype.n", "croptype.nleach", "B_GWL_CLASS"), 
-              by.y = c("bodem", "gewas", "B_GT"), sort =FALSE, all.x = TRUE)
+              by.y = c("bodem", "gewas", "B_GWL_CLASS"), sort =FALSE, all.x = TRUE)
   
   # select the allowed effective N dose (in Dutch: N-gebruiksnorm), being dependent on soil type and region
   sand.south <- c('Zuid-Limburg','Zuidelijk Veehouderijgebied','Zuidwest-Brabant')
